==> bizon-0.0.3.dev1.tar.gz: bizon-0.0.3.dev1/bizon/engine/config.py <==
from typing import Union

from pydantic import BaseModel, ConfigDict, Field

from .backend.adapters.sqlalchemy.config import (
    BigQuerySQLAlchemyConfig,
    PostgresSQLAlchemyConfig,
    SQLiteConfigDetails,
    SQLiteInMemoryConfig,
    SQLiteSQLAlchemyConfig,
)
from .backend.config import BackendTypes
from .queue.adapters.kafka.config import KafkaConfig
from .queue.adapters.python_queue.config import (
    PythonQueueConfig,
    PythonQueueConfigDetails,
    PythonQueueConsumerConfig,
    PythonQueueQueueConfig,
)
from .queue.adapters.rabbitmq.config import RabbitMQConfig
from .queue.config import QueueTypes
from .runners.config import RunnerConfig, RunnerTypes, ThreadsConfig


class EngineConfig(BaseModel):

    # Forbid extra keys in the model
    model_config = ConfigDict(extra="forbid")

    backend: Union[
        PostgresSQLAlchemyConfig,
        SQLiteInMemoryConfig,
        SQLiteSQLAlchemyConfig,
        BigQuerySQLAlchemyConfig,
    ] = Field(
        description="Configuration for the backend",
        default=SQLiteInMemoryConfig(
            type=BackendTypes.SQLITE_IN_MEMORY,
            config=SQLiteConfigDetails(
                database="NOT_USED_IN_SQLITE",
                schema="NOT_USED_IN_SQLITE",
            ),
            syncCursorInDBEvery=2,
        ),
        discriminator="type",
    )

    queue: Union[
        KafkaConfig,
        RabbitMQConfig,
        PythonQueueConfig,
    ] = Field(
        description="Configuration for the queue",
        default=PythonQueueConfig(
            type=QueueTypes.PYTHON_QUEUE,
            config=PythonQueueConfigDetails(
                queue=PythonQueueQueueConfig(max_size=1000),
                consumer=PythonQueueConsumerConfig(poll_interval=2),
            ),
        ),
        discriminator="type",
    )

    runner: RunnerConfig = Field(
        description="Runner to use for the pipeline",
        default=RunnerConfig(
            type=RunnerTypes.THREADS,
            config=ThreadsConfig(
                consumer_start_delay=2,
            ),
            log_level="INFO",
        ),
    )

==> bizon-0.0.4.dev2.tar.gz: bizon-0.0.4.dev2/bizon/engine/config.py <==
from typing import Union

from pydantic import BaseModel, ConfigDict, Field

from .backend.adapters.sqlalchemy.config import (
    BigQuerySQLAlchemyConfig,
    PostgresSQLAlchemyConfig,
    SQLiteConfigDetails,
    SQLiteInMemoryConfig,
    SQLiteSQLAlchemyConfig,
)
from .backend.config import BackendTypes
from .queue.adapters.kafka.config import KafkaConfig
from .queue.adapters.python_queue.config import (
    PythonQueueConfig,
    PythonQueueConfigDetails,
    PythonQueueConsumerConfig,
    PythonQueueQueueConfig,
)
from .queue.adapters.rabbitmq.config import RabbitMQConfig
from .queue.config import QueueTypes
from .runners.config import RunnerConfig, RunnerFuturesConfig, RunnerTypes


class EngineConfig(BaseModel):

    # Forbid extra keys in the model
    model_config = ConfigDict(extra="forbid")

    backend: Union[
        PostgresSQLAlchemyConfig,
        SQLiteInMemoryConfig,
        SQLiteSQLAlchemyConfig,
        BigQuerySQLAlchemyConfig,
    ] = Field(
        description="Configuration for the backend",
        default=SQLiteSQLAlchemyConfig(
            type=BackendTypes.SQLITE,
            config=SQLiteConfigDetails(
                database="bizon",
                schema="NOT_USED_IN_SQLITE",
            ),
            syncCursorInDBEvery=2,
        ),
        discriminator="type",
    )

    queue: Union[
        KafkaConfig,
        RabbitMQConfig,
        PythonQueueConfig,
    ] = Field(
        description="Configuration for the queue",
        default=PythonQueueConfig(
            type=QueueTypes.PYTHON_QUEUE,
            config=PythonQueueConfigDetails(
                queue=PythonQueueQueueConfig(max_size=0),
                consumer=PythonQueueConsumerConfig(poll_interval=2),
            ),
        ),
        discriminator="type",
    )

    runner: RunnerConfig = Field(
        description="Runner to use for the pipeline",
        default=RunnerConfig(
            type=RunnerTypes.THREAD,
            config=RunnerFuturesConfig(),
            log_level="INFO",
        ),
    )
